Juan Hernandez has uploaded a new change for review.

Change subject: packaging: Retry inmediately failed AJP connection
......................................................................

packaging: Retry inmediately failed AJP connection

The configuration that we currently use to connect to the
application server using AJP is the folliwing:

  ProxyPass / ajp://localhost:8009/

This means that the web server will use the default value of 60
seconds for the "retry" parameter. This parameter controls how
long will the web server wait before retrying a failed AJP
connection. For us it means that if we do something like "service
ovirt-engine restart" the web server will force us to wait 60
seconds regardless of how long it takes to restart the engine. In
environments with several application servers this makes sense,
but with only one application server it is better to wait less, or
nothing. This is what we do in this change:

  ProxyPass / ajp://localhost:8009/ retry=0

This means that the web server will inmediately try to reconnect
after a failure.

Change-Id: Ia8291e0671c2feab0e0ae2878795ad5be2c17cc4
Signed-off-by: Juan Hernandez <juan.hernan...@redhat.com>
---
M packaging/fedora/setup/engine-setup.py
1 file changed, 4 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.ovirt.org:29418/ovirt-engine refs/changes/43/7343/1

diff --git a/packaging/fedora/setup/engine-setup.py 
b/packaging/fedora/setup/engine-setup.py
index 068e121..5a88c71 100755
--- a/packaging/fedora/setup/engine-setup.py
+++ b/packaging/fedora/setup/engine-setup.py
@@ -724,9 +724,11 @@
 
 def _redirectUrl():
     try:
         # Redirect everything to the application server using the AJP protocol
         logging.debug("Redirect oVirt URLs using AJP protocol")
-        redirectStr="ProxyPass / ajp://localhost:%s/"%(basedefs.JBOSS_AJP_PORT)
+        redirectStr="ProxyPass / ajp://localhost:%s/ retry=0" 
%(basedefs.JBOSS_AJP_PORT)
 
         fd = open(basedefs.FILE_OVIRT_HTTPD_CONF, 'w')
@@ -724,9 +724,11 @@
 def _redirectUrl():
     try:
-        # Redirect everything to the application server using the AJP protocol
+        # Redirect everything to the application server using the
+        # AJP protocol and configuring the proxy so that it will
+        # retry inmediately a failed connection:
         logging.debug("Redirect oVirt URLs using AJP protocol")
         fd.write(redirectStr)


--
To view, visit http://gerrit.ovirt.org/7343
To unsubscribe, visit http://gerrit.ovirt.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ia8291e0671c2feab0e0ae2878795ad5be2c17cc4
Gerrit-PatchSet: 1
Gerrit-Project: ovirt-engine
Gerrit-Branch: master
Gerrit-Owner: Juan Hernandez <juan.hernan...@redhat.com>
_______________________________________________
Engine-patches mailing list
Engine-patches@ovirt.org
http://lists.ovirt.org/mailman/listinfo/engine-patches

Reply via email to